`go_to_github` is a tool to test whether `github.com` is reachable right now. If not, it will work it out automatically.

# Notice
This project only applies to `macOS` and `Linux`.
It might be in need for people who come from coutries blocking github.

# Usage
On your terminal:
```python
# don't forget `sudo`
# since github ip will be updated if it cannot connect to github.com
# in your `\private\etc\hosts` file, which requires root user 
sudo gotogithub
```
# Installation
```python
pip install go_to_github
```


